<?php
/*******************************************************
Trovate questo e altri script su http://www.manuelmarangoni.it , descritti e commentati nei dettagli.

Autore: Manuel Marangoni
Data messa online dello script: 9 febbraio 2012

Lo script mostra come creare una struttura funzionale e adattabile per la costruzione di un sito web.
Per una descrizione completa e approfondita delle funzioni e del loro uso, si faccia riferimento all'articolo presente all'indirizzo:
http://www.manuelmarangoni.it/sir-bit/983/limportanza-di-una-buona-struttura-per-un-sito-web-con-luso-di-funzioni-php-parte-1/
*******************************************************/ 

/*
DESCRIZIONE GENERALE
head() e footer() sono rispettivamente le funzioni che, se richiamate in altre pagine, stampano a video l'header e il footer.
Le altre funzioni, da richiamare in mezzo a queste, stampano invece il corpo della pagina. Devono essere richiamate a due a due: se per esempio si richiama content_singolo(), seguirà il corpo della pagina e quindi si dovrà chiudere con content_singolo_close().
- content_singolo() : corpo della pagina senza sidebar sinistra e senza sidebar destra
- content() :  corpo della pagina con sidebar sinistra e senza sidebar destra
- content_doppio() : corpo della pagina con sidebar sinistra e sidebar destra
Per un esempio vedere il contenuto nella cartella "pagina_di_esempio", dove viene mostrata una pagina richiamata tramite questa struttura.
*/

include("config.inc.php"); //inclusione del file di connessione al database
include("variabili.inc.php"); //inclusione delle variabili richiamabili in ogni pagina
include("function.inc.php"); //inclusione delle funzioni richiamabili in ogni pagina


/*
Le seguenti variabili sono da inizializzare in testa alle altre pagine, prima di richiamare la funzione head() qui sotto. Nessuna delle variabili è obbligatoria.
- $style è un array che contiene l'indirizzo del foglio di stile da caricare (a partire dalla path base); se per esempio lo style è nella cartella "login", si dovrà salvare la variabile con: $style[]=$http."login/style.css";
- $js ha lo stesso funzionamento di $style, usato per i javascript inclusi
- $nome_pagina è l'eventuale nome della pagina, variabile da usare come eccezione per determinate pagine (es: se nell'home non voglio visualizzare l'header, creo un if di eccezione per $nome_pagina="home";
*/

function head($nome_pagina=""){
	
	//trovandoci all'interno di una funzione, le variabili richiamate devo essere rese globali
	//l'alternativa è l'uso della funzione $GLOBALS per ognuna, es: $GLOBALS['http'];
	global $http, $tab, $db, $style, $js, $favicon;
	?>
	<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
	<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
	
		<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
		<meta name="keywords" content="" />
		<meta name="description" content="Struttura di esempio per siti web" />
		<meta http-equiv="Pragma" content="no-cache" />
		<meta content="no-cache" http-equiv="no-cache" />
		<meta http-equiv="Cache-Control" content="no-cache" />
		<meta http-equiv="expires" content="0" />
		<meta name="author" content="Marangoni Manuel" />
		<meta name="robots" content="index, follow" />
		<meta name="googlebot" content="index, follow" />
		<meta name="copyright" content="Copyright (c) 2012 by Marangoni Manuel" />
		<title>Struttura di esempio per siti web - Manuel Marangoni - <?php echo $nome_pagina;?></title>
		
		<?php 
		//eventuale favicon
		if($favicon!=""){?>
			<link rel="shortcut icon" href="<?php echo $http.$favicon; ?>" />
		<?php }?>
		
        <!-- foglio di stile che formatta le classi di questa struttura -->
		<link rel="stylesheet" type="text/css" href="<?php echo $http;?>style.css">
        
		<?php
		//richiamo i fogli di stile passati come array prima dell'head; se non sono stati passati fogli di stile, $style è una stringa e quindi il contenuto dell'if viene ignorato
		if(is_array($style)){
			foreach($style as $value){?>
				<link rel="stylesheet" type="text/css" href="<?php echo $value; ?>">
			<?php
			}
		}
		?>
		
        <!-- richiamo del file che contiene le funzioni javascript comuni a tutte le pagine -->
		<script type="text/javascript" src="<?php echo $http; ?>javascript.js"></script>
		
		<?php
		//richiamo i javascript passati in un array prima dell'head; se non sono stati passati javascript, $js è una stringa e quindi il contenuto dell'if viene ignorato
		if(is_array($js)){
			foreach($js as $value){?>
				<script type="text/javascript" src="<?php echo $value; ?>"></script>
			<?php
			}
		}
		?>
	
	</head>
	
	<body>
	
		<div id="container">
			
			<div id="header">
				
				CONTENUTO DELL'HEADER

			</div> <!-- header -->
			
			<div class="clear"></div>
			
<?php
}
?>



<?php
/*** corpo della pagina: corpo senza sidebar ***/
function content_singolo(){
	global $http, $tab, $db;
	?>
			<div id="content">
				
				<div id="content_interno_singolo">
	
<?php
}


function content_singolo_close(){
	global $http, $tab, $db;
	?>
				</div> <!-- content_interno singolo -->
				
				<div class="clear"></div>
			
			</div> <!-- content -->
<?php
}
/*** fine corpo della pagina: corpo senza sidebar ***/
?>



<?php
/*** corpo della pagina: sidebar sinistra + corpo ***/
function content($nome_pagina=""){
	global $http, $tab, $db;
	?>
			<div id="content">
			
				<div id="navigation">
					<?php 
					//inclusione della sidebar sinistra
					include("navigation.inc.php");?>
				</div> <!-- navigation -->
				
				<div id="content_interno">
	
<?php
}


function content_close(){
?>
				</div> <!-- content_interno -->
				
				<div class="clear"></div>
			
			</div> <!-- content -->
<?php
}
/*** fine corpo della pagina: sidebar sinistra + corpo ***/
?>



<?php
/*** corpo della pagina: sidebar sinistra + corpo + sidebar destra ***/
function content_doppio($nome_pagina=""){
	global $http, $tab, $db;
	?>
			<div id="content">
			
				<div id="navigation">
					<?php 
					//inclusione della sidebar sinistra
					include("navigation.inc.php");?>
				</div> <!-- navigation -->
				
				<div id="content_doppio_interno">
	
<?php
}


function content_doppio_close($nome_pagina=""){
?>
				</div> <!-- content_doppio_interno -->
				
				<div id="sidebar">
					<?php 
					//inclusione della sidebar sinistra
					include("sidebar.inc.php");?>
				</div> <!-- sidebar -->
				
				<div class="clear"></div>
			
			</div> <!-- content -->
<?php
}
/*** fine corpo della pagina: sidebar sinistra + corpo + sidebar destra ***/
?>




<?php
function footer(){ 

	global $http, $tab, $db;
	?>
			
			<div class="clear"></div>
			
			<div id="footer">
				
				CONTENUTO DEL FOOTER
				
			</div> <!-- footer -->
		
		</div> <!-- container -->
	
	</body>
	</html>
	
	<?php
	//chiusura della connessione al database
	mysql_close($db);

}
?>